@@ -2355,7 +2355,7 @@
         }
         async sendRequest(type, data) {
             return new Promise((resolve, reject) => {
-                chrome.runtime.sendMessage({type, ...data}, ({data, error}) => {
+                chrome.runtime.sendMessage({type, data}, ({data, error}) => {
                     if (error) {
                         reject(error);
                     } else {
@@ -2376,7 +2376,7 @@
                     }
                     dataPort.disconnect();
                 });
-                data && dataPort.postMessage(data);
+                data && dataPort.postMessage({data});
             });
         }
         async getData() {
@@ -2444,12 +2444,12 @@
             if (isFirefox) {
                 return await this.firefoxSendRequestWithResponse(
                     MessageType.UI_APPLY_DEV_DYNAMIC_THEME_FIXES,
-                    {data: text}
+                    text
                 );
             }
             return await this.sendRequest(
                 MessageType.UI_APPLY_DEV_DYNAMIC_THEME_FIXES,
-                {data: text}
+                text
             );
         }
         resetDevDynamicThemeFixes() {
@@ -2461,12 +2461,12 @@
             if (isFirefox) {
                 return await this.firefoxSendRequestWithResponse(
                     MessageType.UI_APPLY_DEV_INVERSION_FIXES,
-                    {data: text}
+                    text
                 );
             }
             return await this.sendRequest(
                 MessageType.UI_APPLY_DEV_INVERSION_FIXES,
-                {data: text}
+                text
             );
         }
         resetDevInversionFixes() {
@@ -2478,12 +2478,12 @@
             if (isFirefox) {
                 return await this.firefoxSendRequestWithResponse(
                     MessageType.UI_APPLY_DEV_STATIC_THEMES,
-                    {data: text}
+                    text
                 );
             }
             return await this.sendRequest(
                 MessageType.UI_APPLY_DEV_STATIC_THEMES,
-                {data: text}
+                text
             );
         }
         resetDevStaticThemes() {
@@ -2502,139 +2502,11 @@
         }
     }
 
-    function getMockData(override = {}) {
-        return Object.assign(
-            {
-                isEnabled: true,
-                isReady: true,
-                settings: {
-                    enabled: true,
-                    fetchNews: true,
-                    presets: [],
-                    theme: {
-                        mode: 1,
-                        brightness: 110,
-                        contrast: 90,
-                        grayscale: 20,
-                        sepia: 10,
-                        useFont: false,
-                        fontFamily: "Segoe UI",
-                        textStroke: 0,
-                        engine: "cssFilter",
-                        stylesheet: "",
-                        scrollbarColor: "auto",
-                        styleSystemControls: true
-                    },
-                    customThemes: [],
-                    siteList: [],
-                    siteListEnabled: [],
-                    applyToListedOnly: false,
-                    changeBrowserTheme: false,
-                    enableForPDF: true,
-                    enableForProtectedPages: false,
-                    syncSettings: true,
-                    automation: "",
-                    time: {
-                        activation: "18:00",
-                        deactivation: "9:00"
-                    },
-                    location: {
-                        latitude: 52.4237178,
-                        longitude: 31.021786
-                    }
-                },
-                fonts: [
-                    "serif",
-                    "sans-serif",
-                    "monospace",
-                    "cursive",
-                    "fantasy",
-                    "system-ui"
-                ],
-                news: [],
-                shortcuts: {
-                    addSite: "Alt+Shift+A",
-                    toggle: "Alt+Shift+D"
-                },
-                devtools: {
-                    dynamicFixesText: "",
-                    filterFixesText: "",
-                    staticThemesText: "",
-                    hasCustomDynamicFixes: false,
-                    hasCustomFilterFixes: false,
-                    hasCustomStaticFixes: false
-                }
-            },
-            override
-        );
-    }
-    function getMockActiveTabInfo() {
-        return {
-            url: "https://darkreader.org/",
-            isProtected: false,
-            isInDarkList: false,
-            isInjected: true
-        };
-    }
-    function createConnectorMock() {
-        let listener = null;
-        const data = getMockData();
-        const tab = getMockActiveTabInfo();
-        const connector = {
-            async getData() {
-                return Promise.resolve(data);
-            },
-            async getActiveTabInfo() {
-                return Promise.resolve(tab);
-            },
-            subscribeToChanges(callback) {
-                listener = callback;
-            },
-            changeSettings(settings) {
-                Object.assign(data.settings, settings);
-                listener(data);
-            },
-            setTheme(theme) {
-                Object.assign(data.settings.theme, theme);
-                listener(data);
-            },
-            setShortcut(command, shortcut) {
-                Object.assign(data.shortcuts, {[command]: shortcut});
-                listener(data);
-            },
-            toggleURL(url) {
-                const pattern = getURLHostOrProtocol(url);
-                const index = data.settings.siteList.indexOf(pattern);
-                if (index >= 0) {
-                    data.settings.siteList.splice(index, 1, pattern);
-                } else {
-                    data.settings.siteList.push(pattern);
-                }
-                listener(data);
-            },
-            markNewsAsRead(ids) {
-                data.news
-                    .filter(({id}) => ids.includes(id))
-                    .forEach((news) => (news.read = true));
-                listener(data);
-            },
-            disconnect() {}
-        };
-        return connector;
-    }
-
-    function connect() {
-        if (typeof chrome === "undefined" || !chrome.extension) {
-            return createConnectorMock();
-        }
-        return new Connector();
-    }
-
     function renderBody(data, tab, actions) {
         sync(document.body, m(Body, {data: data, tab: tab, actions: actions}));
     }
     async function start() {
-        const connector = connect();
+        const connector = new Connector();
         window.addEventListener("unload", () => connector.disconnect());
         const data = await connector.getData();
         const tab = await connector.getActiveTabInfo();
